@@ -58,20 +58,20 @@ def deploy(args):
                         for key,value in task['data']['env'].items():
                             f.write('{key}={value}\r\n'.format(key=key,value=value))
                         f.close()
-                    #if 'config' in task['data']:
-                    if 'source' in task['data']:
-                        if isLinux :
-                            serverDest = server + '/'
-                            f = open(serverDest + task['data']['dest'] + '/config.js', "w+")
-                        else:
-                            serverDest = '\\\\' + server + '\\' 
-                            f = open(serverDest + task['data']['dest'] + '\\config.js', "w+")
-                        json_formatted_str = "var config = " + json.dumps(task['data']['config'],indent=4) 
-                        f.write(json_formatted_str)
-                        f.write("\n")
-                        f.write("\n")
-                        f.write("var __config = {...config}")
-                        f.close()
+                    if 'config' in task['data']:
+                        if 'source' in task['data']:
+                            if isLinux :
+                                serverDest = server + '/'
+                                f = open(serverDest + task['data']['dest'] + '/config.js', "w+")
+                            else:
+                                serverDest = '\\\\' + server + '\\' 
+                                f = open(serverDest + task['data']['dest'] + '\\config.js', "w+")
+                            json_formatted_str = "var config = " + json.dumps(task['data']['config'],indent=4) 
+                            f.write(json_formatted_str)
+                            f.write("\n")
+                            f.write("\n")
+                            f.write("var __config = {...config}")
+                            f.close()
                     if 'local' in task['data']:
                         if isLinux :
                             serverDest = server + '/'
